inline Priority SyslogStream::priority()   const       
{
    return SyslogBuf::priority();
}
